==> savane-1.0.5a.tar.gz: savane/frontend/php/include/menu.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: menu.php,v 1.116 2004/11/26 15:50:33 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
#                          Yves Perrin <yves.perrin--at--cern.ch>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


function menu_print_sidebar($params) 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_print_sidebar($params) ';
  global $HTML;
  
  print '
 <ul class="menu">
        <li class="menulogo">
';

  if ($GLOBALS['sys_logo_name']) 
    {
      print '          '.utils_link($GLOBALS['sys_home'], html_image($GLOBALS['sys_logo_name'],array('alt'=>sprintf(_("Back to %s Homepage"), $GLOBALS['sys_name'])), 0));
    }
  else
    {
      print '          <br />'.utils_link($GLOBALS['sys_home'], $GLOBALS['sys_name'], 0, 1, sprintf(_("Back to %s Homepage"), $GLOBALS['sys_name']));
    }

  print '
        </li><!-- end menulogo -->';  
  if (!user_isloggedin()) 
    {
      print menu_notloggedin();
    } 
  else
    {
      print menu_loggedin($params['title'], $params['toptab'], $params['group']);
    }
  print menu_thispage();
  print menu_search();
  # Site Admin menu added here
  if (user_is_super_user()) 
    {
      print menu_site_admin();
    }
  print menu_projects();
  print menu_help();
  print menu_documentation();
  # Valid HTML is now part of the site specific content
  utils_get_content("menu");
  
  print '
 </ul><!-- end menu -->
';

}


# Menu entry  for all admin tasks when logged as site administor
function menu_site_admin() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_site_admin() ';
    
  global $HTML;
  $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Administration")); 
  $HTML->menu_entry($GLOBALS['sys_home'].'admin/',_("Main page"));
  $HTML->menu_entry($GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;go_report=Apply',_("Pending projects"));
  $HTML->menu_entry($GLOBALS['sys_home'].'news/approve.php?group='.$GLOBALS['sys_unix_group_name'],_("Site news approval"));

  $HTML->menuhtml_bottom();

}

function menu_search() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_search() ';
  global $HTML,$group_id;
  $HTML->menuhtml_top(_("Search"));
  print '       <li class="menusearch">';
  search_box();  
  print '       </li><!-- end menusearch -->';
  $HTML->menuhtml_bottom();
}


#deprecated - theme wrapper
function menuhtml_top($title) 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menuhtml_top() ';
  /*
		Use only for the top most menu
  */
  theme_menuhtml_top($title);
}

# Hosted projects
function menu_projects() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_projects() ';
  global $HTML;
  $HTML->menuhtml_top(_("Hosted Projects"));
  $HTML->menu_entry($GLOBALS['sys_home'].'register/',
		    _("Register New Project"), 
		    user_isloggedin(),
		    sprintf(_("Register your project at %s"),$GLOBALS['sys_name']));
 $HTML->menu_entry($GLOBALS['sys_home'].'search/index.php?type_of_search=soft&amp;words=%%%',
		   _("Full List"),
		   1,
		   _("Browse the full list of hosted projects"));
 $HTML->menu_entry($GLOBALS['sys_home'].'stats/',
		   _("Statistics"),
		   1,
		   sprintf(_("Browse statistics about %s"),$GLOBALS['sys_name']));
  $HTML->menuhtml_bottom();
}

# Toolbox: not very happy with the name "This Page"... please propose
# something better
function  menu_thispage()
{
  global $HTML;
  # FIXME: does not handle the /users and /projects cases
  $HTML->menuhtml_top(_("This Page"));
  if ($_SERVER["REQUEST_METHOD"] == "POST") 
    {
      if ($GLOBALS['group_name'])
	{ $extraurl .= "group=".$GLOBALS['group_name']."&amp;"; }
      if ($GLOBALS['item_id'])
	{ $extraurl .= "func=detailitem&amp;item_id=".$GLOBALS['item_id']."&amp;"; }
    }
  else
    {
      $extraurl = $_SERVER["QUERY_STRING"];
    }

  $HTML->menu_entry($_ENV["SCRIPT_NAME"]."?reload=1&amp;".$extraurl,
		    _("Clean Reload"),
		    1,
		    _("Reload the page without risk of reposting data"));
  $HTML->menu_entry($_ENV["SCRIPT_NAME"]."?printer=1&amp;".$extraurl,
		    _("Printer Version"), 
		    1,
		    _("Show this page with a style adapted to printers"));
  $HTML->menuhtml_bottom();
}

# Savannah Help (dynamic help)
function menu_help() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_help() ';
  global $HTML;
  $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Help"));
  $HTML->menu_entry($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],
		    _("Get Support"),
		    1,
		    sprintf(_("Get help from the Admins of %s"), $GLOBALS['sys_name']));
  $HTML->menu_entry($GLOBALS['sys_home'].'people/',
		    _("Contributor Wanted"),
		    1,
		    _("Browse the list of request for contributions"));
  $HTML->menuhtml_bottom();
}

# Savannah Documentation (static help)
function menu_documentation() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_documentation() ';
  GLOBAL $HTML;
  $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Documentation"));
  $HTML->menu_entry($GLOBALS['sys_home'].'faq/?group='.$GLOBALS['sys_unix_group_name'],
		    _("User Docs (FAQ)"),
		    1,
		    _("Documentation dedicated to any users, including Project Admins"));
  if (user_can_be_super_user()) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php',_("Server Admin Docs"));
      if ($GLOBALS['sys_localdoc_file'])
	{
	  $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php?local=1',_("Local Server Admin Docs"));
	}
    }

  if ($GLOBALS['sys_mrtg_dir'] || $GLOBALS['sys_webalizer_dir']) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'docs/webalizer.php',_("Statistics"));
    }
  $HTML->menu_entry($GLOBALS['sys_home'].'contact.php',
		    _("Contact Us"),
		    1,
		    sprintf(_("Contact address of %s Admins"),$GLOBALS['sys_name']));
  $HTML->menuhtml_bottom();
}

function menu_loggedin($page_title, $page_toptab=0, $page_group=0) 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_loggedin($page_title) ';
  global $HTML;
  /*
		Show links appropriate for someone logged in, like account maintenance, etc
  */
  if (!user_is_super_user()) 
    {
      $HTML->menuhtml_top(sprintf(_("Logged in as %s"), user_getname()));
    }
  else
    {
      $HTML->menuhtml_top('<font class="warn">'.sprintf(_("%s logged in as superuser"), user_getname()).'</font>');
    }
  if (user_can_be_super_user() && !user_is_super_user()) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=login&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), 
			_("Become Superuser"),
			1,
			_("Superuser rights are required to perform site admin tasks"));      
    }
  $HTML->menu_entry($GLOBALS['sys_home'].'my/',
		    _("My Items"),
		    1,
		    _("Browse my items (bugs, tasks, bookmarks...)"));
  $HTML->menu_entry($GLOBALS['sys_home'].'my/groups.php',
		    _("My Groups"),
		    1,
		    _("List the groups I belong to"));
  $HTML->menu_entry($GLOBALS['sys_home'].'account/',
		    _("My Account Conf"),
		    1,
		    _("Account configuration: authentication, cosmetics preferences..."));
  if (!$GLOBALS['HTTP_POST_VARS']) 
    {
      $bookmark_title = "";
      if ($page_toptab) 
	{ $bookmark_title .= urlencode(title_toptab($page_toptab, $page_group)); }
      if ($page_title) 
	{ $bookmark_title .= urlencode(_(": ").$page_title); }


      $HTML->menu_entry($GLOBALS['sys_home'].'my/bookmark_add.php?bookmark_url='.urlencode($GLOBALS['REQUEST_URI']).'&amp;bookmark_title='.$bookmark_title,_("Bookmark This Page"));
    }

 if (user_is_super_user()) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=logout&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), 
			_("Logout Superuser"),
			1,
			_("End the Superuser session, go back to normal user session"));      
    }
  $HTML->menu_entry($GLOBALS['sys_home'].'account/logout.php',
		    _("Logout"),
		    1,
		    _("End the session, remove the session cookie"));
  $HTML->menuhtml_bottom();
}

function menu_notloggedin() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_notloggedin() ';
  global $HTML;
  $HTML->menuhtml_top(_("Login Status:"));
  print '
        <li class="menuitem"> <font class="error">'._("Not Logged In").'</font></li>';
  $HTML->menu_entry($GLOBALS['sys_home'].'faq/?question='.urlencode("1._Why_log_in.txt"),_("Why Log In?"));
  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($GLOBALS['REQUEST_URI']),
		    _("Login via SSL"),
		    1,
		    _("Login page - you must have registered an account first"));
  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/register.php',
		    _("New User via SSL"),
		    1,
		    _("Account registration form"));
  $HTML->menuhtml_bottom();
}

?>

==> savane-1.0.6.tar.gz: savane/frontend/php/include/menu.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: menu.php,v 1.118 2005/03/16 11:34:01 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
#                          Yves Perrin <yves.perrin--at--cern.ch>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


function menu_print_sidebar($params) 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_print_sidebar($params) ';
  global $HTML;
  
  print '
 <ul class="menu">
        <li class="menulogo">
';

  if ($GLOBALS['sys_logo_name']) 
    {
      print '          '.utils_link($GLOBALS['sys_home'], html_image($GLOBALS['sys_logo_name'],array('alt'=>sprintf(_("Back to %s Homepage"), $GLOBALS['sys_name'])), 0));
    }
  else
    {
      print '          <br />'.utils_link($GLOBALS['sys_home'], $GLOBALS['sys_name'], 0, 1, sprintf(_("Back to %s Homepage"), $GLOBALS['sys_name']));
    }

  print '
        </li><!-- end menulogo -->';  
  if (!user_isloggedin()) 
    {
      print menu_notloggedin();
    } 
  else
    {
      print menu_loggedin($params['title'], $params['toptab'], $params['group']);
    }
  print menu_thispage($params['title'], $params['toptab'], $params['group']);
  print menu_search();
  # Site Admin menu added here
  if (user_is_super_user()) 
    {
      print menu_site_admin();
    }
  print menu_projects();
  print menu_help();
  print menu_documentation();
  # Valid HTML is now part of the site specific content
  utils_get_content("menu");
  
  print '
 </ul><!-- end menu -->
';

}


# Menu entry  for all admin tasks when logged as site administor
function menu_site_admin() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_site_admin() ';
    
  global $HTML;
  $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Administration")); 
  $HTML->menu_entry($GLOBALS['sys_home'].'admin/',_("Main page"));
  $HTML->menu_entry($GLOBALS['sys_home'].'task/?group='.$GLOBALS['sys_unix_group_name'].'&amp;category_id=1&amp;status_id=1&amp;set=custom',_("Pending projects"));
  $HTML->menu_entry($GLOBALS['sys_home'].'news/approve.php?group='.$GLOBALS['sys_unix_group_name'],_("Site news approval"));

  $HTML->menuhtml_bottom();

}

function menu_search() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_search() ';
  global $HTML,$group_id;
  $HTML->menuhtml_top(_("Search"));
  print '       <li class="menusearch">';
  search_box();  
  print '       </li><!-- end menusearch -->';
  $HTML->menuhtml_bottom();
}


#deprecated - theme wrapper
function menuhtml_top($title) 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menuhtml_top() ';
  /*
		Use only for the top most menu
  */
  theme_menuhtml_top($title);
}

# Hosted projects
function menu_projects() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_projects() ';
  global $HTML;
  $HTML->menuhtml_top(_("Hosted Projects"));
  $HTML->menu_entry($GLOBALS['sys_home'].'register/',
		    _("Register New Project"), 
		    user_isloggedin(),
		    sprintf(_("Register your project at %s"),$GLOBALS['sys_name']));
 $HTML->menu_entry($GLOBALS['sys_home'].'search/index.php?type_of_search=soft&amp;words=%%%',
		   _("Full List"),
		   1,
		   _("Browse the full list of hosted projects"));
 $HTML->menu_entry($GLOBALS['sys_home'].'stats/',
		   _("Statistics"),
		   1,
		   sprintf(_("Browse statistics about %s"),$GLOBALS['sys_name']));
  $HTML->menuhtml_bottom();
}

# Toolbox: not very happy with the name "This Page"... please propose
# something better
function  menu_thispage($page_title, $page_toptab=0, $page_group=0)
{
  global $HTML;
  # FIXME: does not handle the /users and /projects cases
  $HTML->menuhtml_top(_("This Page"));
  if ($_SERVER["REQUEST_METHOD"] == "POST") 
    {
      if ($GLOBALS['group_name'])
	{ $extraurl .= "&amp;group=".htmlentities($GLOBALS['group_name'])."&amp;"; }
      if ($GLOBALS['item_id'])
	{ $extraurl .= "&amp;func=detailitem&amp;item_id=".htmlentities($GLOBALS['item_id'])."&amp;"; }
    }
  else
    {
      $extraurl = htmlentities($_SERVER["QUERY_STRING"]);
      $extraurl = str_replace("reload=1&amp;", "", $extraurl);
      $extraurl = str_replace("printer=1&amp;", "", $extraurl);
      $extraurl = "&amp;".$extraurl;
    }
  
  $HTML->menu_entry($_ENV["SCRIPT_NAME"]."?reload=1".$extraurl,
		    _("Clean Reload"),
		    1,
		    _("Reload the page without risk of reposting data"));
  $HTML->menu_entry($_ENV["SCRIPT_NAME"]."?printer=1".$extraurl,
		    _("Printer Version"), 
		    1,
		    _("Show this page with a style adapted to printers"));
  $HTML->menuhtml_bottom();

  if (!$GLOBALS['HTTP_POST_VARS']) 
    {
      if (user_isloggedin() && user_get_preference("use_bookmarks"))
	{
	  $bookmark_title = "";
	  if ($page_toptab) 
	    { $bookmark_title .= urlencode(title_toptab($page_toptab, $page_group)); }
	  if ($page_title) 
	    { $bookmark_title .= urlencode(_(": ").$page_title); }

	  if ($GLOBALS[item_id] && ARTIFACT && is_numeric($GLOBALS[item_id]))
	    {
	      $bookmark_title .= urlencode(" - ".ARTIFACT." #".$GLOBALS[item_id]);
	    }
	  
	  $HTML->menu_entry($GLOBALS['sys_home'].'my/bookmarks.php?add=1&amp;url='.urlencode($GLOBALS['REQUEST_URI']).'&amp;title='.$bookmark_title,
			    _("Bookmark It"),
			    1,
			    _("Add this page to my bookmarks"));
	}
    }
  
}

# Savannah Help (dynamic help)
function menu_help() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_help() ';
  global $HTML;
  $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Help"));
  $HTML->menu_entry($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],
		    _("Get Support"),
		    1,
		    sprintf(_("Get help from the Admins of %s"), $GLOBALS['sys_name']));
  $HTML->menu_entry($GLOBALS['sys_home'].'people/',
		    _("Contributor Wanted"),
		    1,
		    _("Browse the list of request for contributions"));
  $HTML->menuhtml_bottom();
}

# Savannah Documentation (static help)
function menu_documentation() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_documentation() ';
  GLOBAL $HTML;
  $HTML->menuhtml_top($GLOBALS['sys_name'].' '._("Documentation"));
  $HTML->menu_entry($GLOBALS['sys_home'].'faq/?group='.$GLOBALS['sys_unix_group_name'],
		    _("User Docs (FAQ)"),
		    1,
		    _("Documentation dedicated to any users, including Project Admins"));
  if (user_can_be_super_user()) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php',_("Server Admin Docs"));
      if ($GLOBALS['sys_localdoc_file'])
	{
	  $HTML->menu_entry($GLOBALS['sys_home'].'docs/admin.php?local=1',_("Local Server Admin Docs"));
	}
    }

  if ($GLOBALS['sys_mrtg_dir'] || $GLOBALS['sys_webalizer_dir']) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'docs/webalizer.php',_("Statistics"));
    }
  $HTML->menu_entry($GLOBALS['sys_home'].'contact.php',
		    _("Contact Us"),
		    1,
		    sprintf(_("Contact address of %s Admins"),$GLOBALS['sys_name']));
  $HTML->menuhtml_bottom();
}

function menu_loggedin($page_title, $page_toptab=0, $page_group=0) 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_loggedin($page_title) ';
  global $HTML;
  /*
		Show links appropriate for someone logged in, like account maintenance, etc
  */
  if (!user_is_super_user()) 
    {
      $HTML->menuhtml_top(sprintf(_("Logged in as %s"), user_getname()));
    }
  else
    {
      $HTML->menuhtml_top('<font class="warn">'.sprintf(_("%s logged in as superuser"), user_getname()).'</font>');
    }
  if (user_can_be_super_user() && !user_is_super_user()) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=login&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), 
			_("Become Superuser"),
			1,
			_("Superuser rights are required to perform site admin tasks"));      
    }
  $HTML->menu_entry($GLOBALS['sys_home'].'my/',
		    _("My Incoming Items"),
		    1,
		    _("What's new for me: new items I should take a look to"));
  $HTML->menu_entry($GLOBALS['sys_home'].'my/items.php',
		    _("My Items"),
		    1,
		    _("Browse my items (submitted by and assigned to...)"));
  $HTML->menu_entry($GLOBALS['sys_home'].'my/groups.php',
		    _("My Groups"),
		    1,
		    _("List the groups I belong to"));
  if (user_get_preference("use_bookmarks")) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'my/bookmarks.php',
			_("My Bookmarks"),
			1,
			_("Show my bookmarks"));
    }

  $HTML->menu_entry($GLOBALS['sys_home'].'account/',
		    _("My Account Conf"),
		    1,
		    _("Account configuration: authentication, cosmetics preferences..."));
  
 if (user_is_super_user()) 
    {
      $HTML->menu_entry($GLOBALS['sys_home'].'account/su.php?action=logout&amp;uri='.urlencode($GLOBALS['REQUEST_URI']), 
			_("Logout Superuser"),
			1,
			_("End the Superuser session, go back to normal user session"));      
    }
  $HTML->menu_entry($GLOBALS['sys_home'].'account/logout.php',
		    _("Logout"),
		    1,
		    _("End the session, remove the session cookie"));
  $HTML->menuhtml_bottom();
}

function menu_notloggedin() 
{
  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':menu_notloggedin() ';
  global $HTML;
  $HTML->menuhtml_top(_("Login Status:"));
  print '
        <li class="menuitem"> <font class="error">'._("Not Logged In").'</font></li>';
  $HTML->menu_entry($GLOBALS['sys_home'].'faq/?question='.urlencode("1._Why_log_in.txt"),_("Why Log In?"));
  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($GLOBALS['REQUEST_URI']),
		    _("Login via SSL"),
		    1,
		    _("Login page - you must have registered an account first"));
  $HTML->menu_entry($GLOBALS['sys_https_url'].$GLOBALS['sys_home'].'account/register.php',
		    _("New User via SSL"),
		    1,
		    _("Account registration form"));
  $HTML->menuhtml_bottom();
}

?>
